summaryrefslogtreecommitdiff
path: root/errors.go
diff options
context:
space:
mode:
Diffstat (limited to 'errors.go')
-rw-r--r--errors.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/errors.go b/errors.go
index 1047704..c9d18cb 100644
--- a/errors.go
+++ b/errors.go
@@ -138,9 +138,9 @@ var (
// ErrDefinedNameScope defined the error message on not found defined name
// in the given scope.
ErrDefinedNameScope = errors.New("no defined name on the scope")
// ErrDefinedNameduplicate defined the error message on the same name
// already exists on the scope.
- ErrDefinedNameduplicate = errors.New("the same name already exists on the scope")
+ ErrDefinedNameDuplicate = errors.New("the same name already exists on the scope")
// ErrCustomNumFmt defined the error message on receive the empty custom number format.
ErrCustomNumFmt = errors.New("custom number format can not be empty")
// ErrFontLength defined the error message on the length of the font
@@ -138,9 +138,9 @@ var (
// in the given scope.
ErrDefinedNameScope = errors.New("no defined name on the scope")
- // ErrDefinedNameduplicate defined the error message on the same name
+ // ErrDefinedNameDuplicate defined the error message on the same name
// already exists on the scope.